@@ -1,17 +1,22 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 import sys, os, string
+from time import gmtime, strftime
 
 poHeader="""# Tuxpaint-stamps [Language] translation.
-# Copyright (C) 2002-2005
+# Copyright (C) 2002-"+"2008"
 # This file is distributed under the same license as the Tuxpaint-stamps package.
-# [Translator's name] <translator@email.address>, 2002-2005.
-#
+# [Translator's name] <translator@email.address>, """+\
+strftime("%Y", gmtime())+"\n"\
+"""#
 msgid ""
 msgstr ""
 "Project-Id-Version: tuxpaint-stamps\\n"
 "Report-Msgid-Bugs-To: tuxpaint-i18n@lists.sourceforge.net\\n"
 "MIME-Version: 1.0\\n"
+"POT-Creation-Date: """+\
+strftime("%Y-%m-%d %H:%M:%S+0000", gmtime())+"\\n\"\n"\
+""""PO-Revision-Date: \\n"
 "Content-Type: text/plain; charset=UTF-8\\n"
 "Content-Transfer-Encoding: 8bit\\n"
 """
@@ -25,7 +30,9 @@ def lister(poLocale, dirname, filesindir):
             # write stamp filename down follow mark('#').
             poFile.write('\n#: ' + dirname + '/' + fnlist[0] + '\n')
             # write description in msgid.
-	    line = txtFile.readline()[:-1]
+	    line = txtFile.readline()
+	    if line[-1:] == "\n" :
+		line = line[:-1]
 	    line = string.replace(line, '"', '\\"')
             poFile.write('msgid "' + line + '"\n')
 	    localeString = ""
